=========
scrapylib
=========

.. image:: https://badge.fury.io/py/scrapylib.png
   :target: http://badge.fury.io/py/scrapylib

.. image:: https://secure.travis-ci.org/scrapinghub/scrapylib.png?branch=master
   :target: http://travis-ci.org/scrapinghub/scrapylib

Overview
========

This is a library that contains a collection of code to use with the Scrapy
framework, including extensions, middlewares, pipelines and helper functions.
